@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -68,7 +68,20 @@ public class CurrencyNames_en_CA extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "CAD", "$" },
-            { "VES", "VES" },
+            { "JPY", "JP\u00a5" },
+            { "USD", "US$" },
+            { "bmd", "Bermudian Dollar" },
+            { "byb", "Belarusian New Rouble (1994\u20131999)" },
+            { "byn", "Belarusian Rouble" },
+            { "byr", "Belarusian Rouble (2000\u20132016)" },
+            { "lvr", "Latvian Rouble" },
+            { "rub", "Russian Rouble" },
+            { "rur", "Russian Rouble (1991\u20131998)" },
+            { "shp", "Saint Helena Pound" },
+            { "stn", "S\u00e3o Tom\u00e9 and Pr\u00edncipe Dobra" },
+            { "tjr", "Tajikistani Rouble" },
+            { "ttd", "Trinidad and Tobago Dollar" },
+            { "xxx", "unknown currency" },
         };
         return data;
     }
