@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -278,6 +278,7 @@ public class CurrencyNames_gd extends OpenListResourceBundle {
             { "SHP", "SHP" },
             { "SIT", "SIT" },
             { "SKK", "SKK" },
+            { "SLE", "SLE" },
             { "SLL", "SLL" },
             { "SOS", "SOS" },
             { "SRD", "SRD" },
@@ -313,6 +314,7 @@ public class CurrencyNames_gd extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEB", "VEB" },
+            { "VED", "VED" },
             { "VEF", "VEF" },
             { "VES", "VES" },
             { "VNN", "VNN" },
@@ -574,6 +576,7 @@ public class CurrencyNames_gd extends OpenListResourceBundle {
             { "shp", "Punnd Eilean Naomh Eilidh" },
             { "sit", "Tolar Sl\u00f2bhaineach" },
             { "skk", "Koruna Sl\u00f2bhacach" },
+            { "sle", "Leone Siarra Le\u00f2mhannach \u00f9r" },
             { "sll", "Leone Siarra Le\u00f2mhannach" },
             { "sos", "Shilling Som\u00e0ilitheach" },
             { "srd", "Dolar Suranamach" },
@@ -611,6 +614,7 @@ public class CurrencyNames_gd extends OpenListResourceBundle {
             { "uyw", "Aonad inneacs tuarastail ainmeach Uruguaidh" },
             { "uzs", "Som Usbagach" },
             { "veb", "Bol\u00edvar Bheinisealach (1871\u20132008)" },
+            { "ved", "Bol\u00edvar Soberano" },
             { "vef", "Bol\u00edvar Bheinisealach (2008\u20132018)" },
             { "ves", "Bol\u00edvar Bheinisealach" },
             { "vnd", "Dong Bhiet-Namach" },
